@@ -3,10 +3,23 @@ import json
 from datetime import timedelta
 from uuid import uuid4
 from flask_redis import FlaskRedis
+from flask import request
 from redis import Redis
 from werkzeug.datastructures import CallbackDict
 from flask.sessions import SessionInterface, SessionMixin
 
+def get_lang(lang):
+    if lang is None:
+        return request.accept_languages.best_match(['zh-TW','zh-CN', 'en']) or 'zh-CN'
+    if lang.lower() in('cn','zh_cn','zh-cn'):
+        return 'zh-CN'
+    elif lang.lower() in('tw','zh_tw','zh-tw'):
+        return 'zh-TW'
+    elif lang.lower() =='en':
+        return 'en'
+    else:
+        return 'en'
+
 class RedisSession(CallbackDict, SessionMixin):
     def __init__(self, initial=None, sid=None, new=False):
         def on_update(self):
@@ -86,7 +99,7 @@ class RedisSessionInterface(SessionInterface):
                                 expires=cookie_exp,
                                 httponly=True,
                                 domain=domain)
-            response.set_cookie('locale', session.get('locale'),
+            response.set_cookie('locale', get_lang(session.get('locale')),
                                 expires=cookie_exp,
                                 httponly=True,
                                 domain=domain
